from inline_snapshot import snapshot

all_endpoints = snapshot(
    [
        "bike_points",
        "car_park",
        "car_park_id",
        "charge_connector",
        "charge_connector_ids",
    ],
)
