from inline_snapshot import snapshot

all_endpoints = snapshot(
    [
        "within_radius",
        "forward_requests",
        "meta_categories",
        "meta_modes",
        "meta_stop_types",
        "mode",
        "mode_disruption",
        "search",
        "search_query",
        "service_types",
        "sms_id",
        "type",
        "type_page",
        "stop_point_ids",
        "stop_point_disruption",
        "arrival_departures",
        "arrivals",
        "can_reach_on_line",
        "crowding",
        "direction_to",
        "route",
        "place_types",
        "car_parks",
        "taxi_ranks",
    ],
)
